var NAVTREEINDEX =
{
"index.html":[],
"index.html":[0],
"pages.html":[1],
"faq.html":[1,0],
"usermanual.html":[1,1],
"manual-page-introduction.html":[1,1,0],
"manual-page-installation.html":[1,1,1],
"manual-page-types.html":[1,1,2],
"manual-page-operations.html":[1,1,3],
"manual-page-algorithms.html":[1,1,4],
"manual-page-interfacing.html":[1,1,5],
"manual-page-memory.html":[1,1,6],
"manual-page-shared-library.html":[1,1,7],
"manual-page-additional-algorithms.html":[1,1,8],
"manual-page-custom-contexts.html":[1,1,9],
"manual-page-multi-device.html":[1,1,10],
"manual-page-custom-kernels.html":[1,1,11],
"manual-page-structured-matrix.html":[1,1,12],
"manual-page-design.html":[1,1,13],
"manual-page-authors.html":[1,1,14],
"manual-page-versioning.html":[1,1,15],
"manual-page-license.html":[1,1,16],
"test.html":[1,2],
"citelist.html":[1,3],
"namespaces.html":[2,0],
"namespacedetail.html":[2,0,0],
"namespaceviennacl.html":[2,0,1],
"namespaceviennacl_1_1backend.html":[2,0,2],
"namespaceviennacl_1_1backend_1_1cpu__ram.html":[2,0,3],
"namespaceviennacl_1_1backend_1_1cpu__ram_1_1detail.html":[2,0,4],
"namespaceviennacl_1_1backend_1_1cuda.html":[2,0,5],
"namespaceviennacl_1_1backend_1_1cuda_1_1detail.html":[2,0,6],
"namespaceviennacl_1_1backend_1_1detail.html":[2,0,7],
"namespaceviennacl_1_1backend_1_1opencl.html":[2,0,8],
"namespaceviennacl_1_1backend_1_1opencl_1_1detail.html":[2,0,9],
"namespaceviennacl_1_1detail.html":[2,0,10],
"namespaceviennacl_1_1detail_1_1fft.html":[2,0,11],
"namespaceviennacl_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[2,0,12],
"namespaceviennacl_1_1device__specific.html":[2,0,13],
"namespaceviennacl_1_1device__specific_1_1autotune.html":[2,0,14],
"namespaceviennacl_1_1device__specific_1_1builtin__database.html":[2,0,15],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices.html":[2,0,16],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator.html":[2,0,17],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1accelerator_1_1fallback.html":[2,0,18],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu.html":[2,0,19],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1cpu_1_1fallback.html":[2,0,20],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu.html":[2,0,21],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd.html":[2,0,22],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen.html":[2,0,23],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1evergreen_1_1cypress.html":[2,0,24],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1northern__islands.html":[2,0,25],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1northern__islands_1_1devastator.html":[2,0,26],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands.html":[2,0,27],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1southern__islands_1_1tahiti.html":[2,0,28],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands.html":[2,0,29],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1amd_1_1volcanic__islands_1_1hawaii.html":[2,0,30],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1fallback.html":[2,0,31],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia.html":[2,0,32],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi.html":[2,0,33],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gt__540m.html":[2,0,34],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1fermi_1_1geforce__gtx__580.html":[2,0,35],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler.html":[2,0,36],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1kepler_1_1tesla__k20m.html":[2,0,37],
"namespaceviennacl_1_1device__specific_1_1detail.html":[2,0,38],
"namespaceviennacl_1_1device__specific_1_1profiles.html":[2,0,39],
"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[2,0,40],
"namespaceviennacl_1_1device__specific_1_1utils.html":[2,0,41],
"namespaceviennacl_1_1io.html":[2,0,42],
"namespaceviennacl_1_1io_1_1detail.html":[2,0,43],
"namespaceviennacl_1_1io_1_1tag.html":[2,0,44],
"namespaceviennacl_1_1io_1_1val.html":[2,0,45],
"namespaceviennacl_1_1linalg.html":[2,0,46],
"namespaceviennacl_1_1linalg_1_1cuda.html":[2,0,47],
"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[2,0,48],
"namespaceviennacl_1_1linalg_1_1cuda_1_1detail_1_1fft.html":[2,0,49],
"namespaceviennacl_1_1linalg_1_1detail.html":[2,0,50],
"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[2,0,51],
"namespaceviennacl_1_1linalg_1_1detail_1_1fft.html":[2,0,52],
"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[2,0,53],
"namespaceviennacl_1_1linalg_1_1host__based.html":[2,0,54],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[2,0,55],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[2,0,56],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[2,0,57],
"namespaceviennacl_1_1linalg_1_1kernels.html":[2,0,58],
"namespaceviennacl_1_1linalg_1_1opencl.html":[2,0,59],
"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html":[2,0,60],
"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[2,0,61],
"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels_1_1detail.html":[2,0,62],
"namespaceviennacl_1_1ocl.html":[2,0,63],
"namespaceviennacl_1_1result__of.html":[2,0,64],
"namespaceviennacl_1_1scheduler.html":[2,0,65],
"namespaceviennacl_1_1scheduler_1_1detail.html":[2,0,66],
"namespaceviennacl_1_1scheduler_1_1preset.html":[2,0,67],
"namespaceviennacl_1_1scheduler_1_1result__of.html":[2,0,68],
"namespaceviennacl_1_1tools.html":[2,0,69],
"namespaceviennacl_1_1tools_1_1detail.html":[2,0,70],
"namespaceviennacl_1_1traits.html":[2,0,71],
"namespacemembers.html":[2,1,0],
"namespacemembers.html":[2,1,0,0],
"namespacemembers.html":[2,1,0,1],
"namespacemembers.html":[2,1,0,2],
"namespacemembers.html":[2,1,0,3],
"namespacemembers.html":[2,1,0,4],
"namespacemembers.html":[2,1,0,5],
"namespacemembers.html":[2,1,0,6],
"namespacemembers.html":[2,1,0,7],
"namespacemembers.html":[2,1,0,8],
"namespacemembers.html":[2,1,0,9],
"namespacemembers.html":[2,1,0,10],
"namespacemembers.html":[2,1,0,11],
"namespacemembers.html":[2,1,0,12],
"namespacemembers.html":[2,1,0,13],
"namespacemembers.html":[2,1,0,14],
"namespacemembers.html":[2,1,0,15],
"namespacemembers.html":[2,1,0,16],
"namespacemembers.html":[2,1,0,17],
"namespacemembers.html":[2,1,0,18],
"namespacemembers.html":[2,1,0,19],
"namespacemembers.html":[2,1,0,20],
"namespacemembers.html":[2,1,0,21],
"namespacemembers.html":[2,1,0,22],
"namespacemembers.html":[2,1,0,23],
"namespacemembers_func.html":[2,1,1],
"namespacemembers_func.html":[2,1,1,0],
"namespacemembers_func.html":[2,1,1,1],
"namespacemembers_func.html":[2,1,1,2],
"namespacemembers_func.html":[2,1,1,3],
"namespacemembers_func.html":[2,1,1,4],
"namespacemembers_func.html":[2,1,1,5],
"namespacemembers_func.html":[2,1,1,6],
"namespacemembers_func.html":[2,1,1,7],
"namespacemembers_func.html":[2,1,1,8],
"namespacemembers_func.html":[2,1,1,9],
"namespacemembers_func.html":[2,1,1,10],
"namespacemembers_func.html":[2,1,1,11],
"namespacemembers_func.html":[2,1,1,12],
"namespacemembers_func.html":[2,1,1,13],
"namespacemembers_func.html":[2,1,1,14],
"namespacemembers_func.html":[2,1,1,15],
"namespacemembers_func.html":[2,1,1,16],
"namespacemembers_func.html":[2,1,1,17],
"namespacemembers_func.html":[2,1,1,18],
"namespacemembers_func.html":[2,1,1,19],
"namespacemembers_func.html":[2,1,1,20],
"namespacemembers_func.html":[2,1,1,21],
"namespacemembers_func.html":[2,1,1,22],
"namespacemembers_vars.html":[2,1,2],
"namespacemembers_type.html":[2,1,3],
"namespacemembers_enum.html":[2,1,4],
"namespacemembers_eval.html":[2,1,5],
"annotated.html":[3,0],
"structviennacl_1_1ocl_1_1accelerator__tag.html":[3,0,0],
"classviennacl_1_1advanced__cuthill__mckee__tag.html":[3,0,1],
"structviennacl_1_1result__of_1_1alignment.html":[3,0,2],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html":[3,0,3],
"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__nonzero__scalar.html":[3,0,4],
"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__point.html":[3,0,5],
"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__pointvector.html":[3,0,6],
"classviennacl_1_1linalg_1_1amg__precond.html":[3,0,7],
"classviennacl_1_1linalg_1_1amg__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html":[3,0,8],
"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__slicing.html":[3,0,9],
"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsematrix.html":[3,0,10],
"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector.html":[3,0,11],
"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__sparsevector__iterator.html":[3,0,12],
"classviennacl_1_1linalg_1_1detail_1_1amg_1_1amg__tag.html":[3,0,13],
"structviennacl_1_1backend_1_1cpu__ram_1_1detail_1_1array__deleter.html":[3,0,14],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html":[3,0,15],
"structviennacl_1_1tools_1_1detail_1_1aux.html":[3,0,16],
"structviennacl_1_1tools_1_1detail_1_1auximpl.html":[3,0,17],
"classviennacl_1_1ocl_1_1backend.html":[3,0,18],
"classviennacl_1_1basic__range.html":[3,0,19],
"classviennacl_1_1basic__slice.html":[3,0,20],
"classviennacl_1_1linalg_1_1bicgstab__tag.html":[3,0,21],
"classviennacl_1_1device__specific_1_1binary__leaf.html":[3,0,22],
"classviennacl_1_1device__specific_1_1bind__all__unique.html":[3,0,23],
"classviennacl_1_1device__specific_1_1bind__to__handle.html":[3,0,24],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1bisect__kernel.html":[3,0,25],
"classviennacl_1_1linalg_1_1block__ilu__precond.html":[3,0,26],
"classviennacl_1_1linalg_1_1block__ilu__precond_3_01compressed__matrix_3_01_numeric_t_00_01_align1f935c0ddb2915c5703380de7539023a.html":[3,0,27],
"classviennacl_1_1linalg_1_1detail_1_1spai_1_1block__matrix.html":[3,0,28],
"classviennacl_1_1linalg_1_1detail_1_1spai_1_1block__vector.html":[3,0,29],
"classviennacl_1_1ocl_1_1build__program__failure.html":[3,0,30],
"classviennacl_1_1linalg_1_1cg__tag.html":[3,0,31],
"structviennacl_1_1device__specific_1_1char__to__type.html":[3,0,32],
"structviennacl_1_1tools_1_1_c_h_e_c_k___s_c_a_l_a_r___t_e_m_p_l_a_t_e___a_r_g_u_m_e_n_t.html":[3,0,33],
"classviennacl_1_1circulant__matrix.html":[3,0,34],
"structviennacl_1_1result__of_1_1cl__type.html":[3,0,35],
"structviennacl_1_1linalg_1_1detail_1_1amg_1_1classcomp.html":[3,0,36],
"structviennacl_1_1col__iteration.html":[3,0,37],
"structviennacl_1_1column__major.html":[3,0,38],
"structviennacl_1_1column__major__tag.html":[3,0,39],
"classviennacl_1_1ocl_1_1command__queue.html":[3,0,40],
"structviennacl_1_1linalg_1_1detail_1_1spai_1_1_compare_second.html":[3,0,41],
"classviennacl_1_1ocl_1_1compiler__not__available.html":[3,0,42],
"classviennacl_1_1compressed__compressed__matrix.html":[3,0,43],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__compressed__matrix.html":[3,0,44],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1compressed__matrix.html":[3,0,45],
"classviennacl_1_1compressed__matrix.html":[3,0,46],
"classviennacl_1_1const__entry__proxy.html":[3,0,47],
"structviennacl_1_1tools_1_1_c_o_n_s_t___r_e_m_o_v_e_r.html":[3,0,48],
"classviennacl_1_1tools_1_1const__sparse__matrix__adapted__iterator.html":[3,0,49],
"classviennacl_1_1tools_1_1const__sparse__matrix__adapter.html":[3,0,50],
"classviennacl_1_1const__vector__iterator.html":[3,0,51],
"classviennacl_1_1ocl_1_1context.html":[3,0,52],
"classviennacl_1_1context.html":[3,0,53],
"structviennacl_1_1backend_1_1detail_1_1convert__to__opencl.html":[3,0,54],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1coordinate__matrix.html":[3,0,55],
"classviennacl_1_1coordinate__matrix.html":[3,0,56],
"classviennacl_1_1tools_1_1detail_1_1count.html":[3,0,57],
"structviennacl_1_1tools_1_1_c_p_u___s_c_a_l_a_r___t_y_p_e___d_e_d_u_c_e_r.html":[3,0,58],
"structviennacl_1_1ocl_1_1cpu__tag.html":[3,0,59],
"structviennacl_1_1result__of_1_1cpu__value__type.html":[3,0,60],
"structviennacl_1_1backend_1_1cuda_1_1detail_1_1cuda__deleter.html":[3,0,61],
"classviennacl_1_1cuda__not__available__exception.html":[3,0,62],
"structviennacl_1_1cuthill__mckee__tag.html":[3,0,63],
"classviennacl_1_1device__specific_1_1builtin__database_1_1database__type.html":[3,0,64],
"structviennacl_1_1tools_1_1detail_1_1default__deleter.html":[3,0,65],
"structviennacl_1_1ocl_1_1default__tag.html":[3,0,66],
"classdense__matrix.html":[3,0,67],
"classviennacl_1_1ocl_1_1device.html":[3,0,68],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__architecture__t.html":[3,0,69],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__name__t.html":[3,0,70],
"classviennacl_1_1ocl_1_1device__not__available.html":[3,0,71],
"classviennacl_1_1ocl_1_1device__not__found.html":[3,0,72],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1device__type__t.html":[3,0,73],
"structviennacl_1_1ocl_1_1_d_o_u_b_l_e___p_r_e_c_i_s_i_o_n___c_h_e_c_k_e_r.html":[3,0,74],
"classviennacl_1_1ocl_1_1double__precision__not__provided__error.html":[3,0,75],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ell__matrix.html":[3,0,76],
"classviennacl_1_1ell__matrix.html":[3,0,77],
"structviennacl_1_1enable__if.html":[3,0,78],
"classviennacl_1_1entry__proxy.html":[3,0,79],
"structviennacl_1_1ocl_1_1error__checker.html":[3,0,80],
"classviennacl_1_1device__specific_1_1tree__parsing_1_1evaluate__expression__traversal.html":[3,0,81],
"classviennacl_1_1device__specific_1_1execution__handler.html":[3,0,82],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1expression__t.html":[3,0,83],
"classviennacl_1_1linalg_1_1detail_1_1_fast_matrix.html":[3,0,84],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1fft.html":[3,0,85],
"classviennacl_1_1device__specific_1_1tree__parsing_1_1filter.html":[3,0,86],
"classviennacl_1_1device__specific_1_1tree__parsing_1_1filter__elements.html":[3,0,87],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01char_01_4.html":[3,0,88],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01double_01_4.html":[3,0,89],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01float_01_4.html":[3,0,90],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01int_01_4.html":[3,0,91],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01long_01_4.html":[3,0,92],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01short_01_4.html":[3,0,93],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01char_01_4.html":[3,0,94],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01int_01_4.html":[3,0,95],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01long_01_4.html":[3,0,96],
"structviennacl_1_1device__specific_1_1utils_1_1first__letter__of__type_3_01unsigned_01short_01_4.html":[3,0,97],
"classviennacl_1_1linalg_1_1fspai__precond.html":[3,0,98],
"classviennacl_1_1linalg_1_1fspai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00e2257d431089a1252a9a2c07955b0dee.html":[3,0,99],
"classviennacl_1_1linalg_1_1detail_1_1spai_1_1fspai__tag.html":[3,0,100],
"classviennacl_1_1device__specific_1_1generator__not__supported__exception.html":[3,0,101],
"structviennacl_1_1gibbs__poole__stockmeyer__tag.html":[3,0,102],
"classviennacl_1_1linalg_1_1gmres__tag.html":[3,0,103],
"structviennacl_1_1ocl_1_1gpu__tag.html":[3,0,104],
"classviennacl_1_1ocl_1_1handle.html":[3,0,105],
"structviennacl_1_1device__specific_1_1utils_1_1handle__fun.html":[3,0,106],
"classviennacl_1_1ocl_1_1handle__inc__dec__helper.html":[3,0,107],
"classviennacl_1_1hankel__matrix.html":[3,0,108],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1hyb__matrix.html":[3,0,109],
"classviennacl_1_1hyb__matrix.html":[3,0,110],
"classviennacl_1_1linalg_1_1ichol0__precond.html":[3,0,111],
"classviennacl_1_1linalg_1_1ichol0__precond_3_01compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html":[3,0,112],
"classviennacl_1_1linalg_1_1ichol0__tag.html":[3,0,113],
"classviennacl_1_1identity__matrix.html":[3,0,114],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ilu.html":[3,0,115],
"classviennacl_1_1linalg_1_1ilu0__precond.html":[3,0,116],
"classviennacl_1_1linalg_1_1ilu0__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html":[3,0,117],
"classviennacl_1_1linalg_1_1ilu0__tag.html":[3,0,118],
"classviennacl_1_1linalg_1_1detail_1_1ilu__vector__range.html":[3,0,119],
"classviennacl_1_1linalg_1_1ilut__precond.html":[3,0,120],
"classviennacl_1_1linalg_1_1ilut__precond_3_01viennacl_1_1compressed__matrix_3_01_numeric_t_00_01_alignment_v_01_4_01_4.html":[3,0,121],
"classviennacl_1_1linalg_1_1ilut__tag.html":[3,0,122],
"classviennacl_1_1ocl_1_1image__format__mismatch.html":[3,0,123],
"classviennacl_1_1ocl_1_1image__format__not__supported.html":[3,0,124],
"classviennacl_1_1implicit__matrix__base.html":[3,0,125],
"classviennacl_1_1implicit__vector__base.html":[3,0,126],
"structviennacl_1_1device__specific_1_1index__tuple.html":[3,0,127],
"structviennacl_1_1linalg_1_1detail_1_1_input_data.html":[3,0,128],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size1__fun.html":[3,0,129],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size2__fun.html":[3,0,130],
"structviennacl_1_1device__specific_1_1utils_1_1internal__size__fun.html":[3,0,131],
"classviennacl_1_1ocl_1_1invalid__arg__index.html":[3,0,132],
"classviennacl_1_1ocl_1_1invalid__arg__size.html":[3,0,133],
"classviennacl_1_1ocl_1_1invalid__arg__value.html":[3,0,134],
"classviennacl_1_1ocl_1_1invalid__binary.html":[3,0,135],
"classviennacl_1_1ocl_1_1invalid__buffer__size.html":[3,0,136],
"classviennacl_1_1ocl_1_1invalid__build__options.html":[3,0,137],
"classviennacl_1_1ocl_1_1invalid__command__queue.html":[3,0,138],
"classviennacl_1_1ocl_1_1invalid__context.html":[3,0,139],
"classviennacl_1_1ocl_1_1invalid__device.html":[3,0,140],
"classviennacl_1_1ocl_1_1invalid__device__type.html":[3,0,141],
"classviennacl_1_1ocl_1_1invalid__event.html":[3,0,142],
"classviennacl_1_1ocl_1_1invalid__event__wait__list.html":[3,0,143],
"classviennacl_1_1ocl_1_1invalid__gl__object.html":[3,0,144],
"classviennacl_1_1ocl_1_1invalid__global__offset.html":[3,0,145],
"classviennacl_1_1ocl_1_1invalid__global__work__size.html":[3,0,146],
"classviennacl_1_1ocl_1_1invalid__host__ptr.html":[3,0,147],
"classviennacl_1_1ocl_1_1invalid__image__format__descriptor.html":[3,0,148],
"classviennacl_1_1ocl_1_1invalid__image__size.html":[3,0,149],
"classviennacl_1_1ocl_1_1invalid__kernel.html":[3,0,150],
"classviennacl_1_1ocl_1_1invalid__kernel__args.html":[3,0,151],
"classviennacl_1_1ocl_1_1invalid__kernel__definition.html":[3,0,152],
"classviennacl_1_1ocl_1_1invalid__kernel__name.html":[3,0,153],
"classviennacl_1_1ocl_1_1invalid__mem__object.html":[3,0,154],
"classviennacl_1_1ocl_1_1invalid__mip__level.html":[3,0,155],
"classviennacl_1_1ocl_1_1invalid__operation.html":[3,0,156],
"classviennacl_1_1ocl_1_1invalid__platform.html":[3,0,157],
"classviennacl_1_1ocl_1_1invalid__program.html":[3,0,158],
"classviennacl_1_1ocl_1_1invalid__program__executable.html":[3,0,159],
"classviennacl_1_1ocl_1_1invalid__property.html":[3,0,160],
"classviennacl_1_1ocl_1_1invalid__queue__properties.html":[3,0,161],
"classviennacl_1_1ocl_1_1invalid__sampler.html":[3,0,162],
"classviennacl_1_1device__specific_1_1template__base_1_1invalid__template__exception.html":[3,0,163],
"classviennacl_1_1ocl_1_1invalid__value.html":[3,0,164],
"classviennacl_1_1ocl_1_1invalid__work__dimension.html":[3,0,165],
"classviennacl_1_1ocl_1_1invalid__work__group__size.html":[3,0,166],
"classviennacl_1_1ocl_1_1invalid__work__item__size.html":[3,0,167],
"structviennacl_1_1is__addition.html":[3,0,168],
"structviennacl_1_1is__any__dense__matrix.html":[3,0,169],
"structviennacl_1_1is__any__dense__structured__matrix.html":[3,0,170],
"structviennacl_1_1is__any__scalar.html":[3,0,171],
"structviennacl_1_1is__any__sparse__matrix.html":[3,0,172],
"structviennacl_1_1is__any__vector.html":[3,0,173],
"structviennacl_1_1is__circulant__matrix.html":[3,0,174],
"structviennacl_1_1is__compressed__matrix.html":[3,0,175],
"structviennacl_1_1is__coordinate__matrix.html":[3,0,176],
"structviennacl_1_1is__cpu__scalar.html":[3,0,177],
"structviennacl_1_1is__division.html":[3,0,178],
"structviennacl_1_1is__eigen.html":[3,0,179],
"structviennacl_1_1is__ell__matrix.html":[3,0,180],
"structviennacl_1_1is__flip__sign__scalar.html":[3,0,181],
"structviennacl_1_1is__hankel__matrix.html":[3,0,182],
"structviennacl_1_1is__hyb__matrix.html":[3,0,183],
"structviennacl_1_1is__mtl4.html":[3,0,184],
"structviennacl_1_1is__primitive__type.html":[3,0,185],
"structviennacl_1_1is__product.html":[3,0,186],
"structviennacl_1_1is__row__major.html":[3,0,187],
"structviennacl_1_1device__specific_1_1utils_1_1is__same__type.html":[3,0,188],
"structviennacl_1_1device__specific_1_1utils_1_1is__same__type_3_01_t_00_01_t_01_4.html":[3,0,189],
"structviennacl_1_1is__scalar.html":[3,0,190],
"structviennacl_1_1is__sliced__ell__matrix.html":[3,0,191],
"structviennacl_1_1is__stl.html":[3,0,192],
"structviennacl_1_1is__subtraction.html":[3,0,193],
"structviennacl_1_1is__toeplitz__matrix.html":[3,0,194],
"structviennacl_1_1is__ublas.html":[3,0,195],
"structviennacl_1_1is__vandermonde__matrix.html":[3,0,196],
"structviennacl_1_1is__viennacl.html":[3,0,197],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1iterative.html":[3,0,198],
"classviennacl_1_1linalg_1_1jacobi__precond.html":[3,0,199],
"classviennacl_1_1linalg_1_1jacobi__precond_3_01_matrix_t_00_01true_01_4.html":[3,0,200],
"classviennacl_1_1linalg_1_1jacobi__tag.html":[3,0,201],
"classviennacl_1_1ocl_1_1kernel.html":[3,0,202],
"classviennacl_1_1device__specific_1_1utils_1_1kernel__generation__stream.html":[3,0,203],
"classviennacl_1_1linalg_1_1lanczos__tag.html":[3,0,204],
"classviennacl_1_1device__specific_1_1lazy__program__compiler.html":[3,0,205],
"structviennacl_1_1device__specific_1_1utils_1_1leading__start.html":[3,0,206],
"structviennacl_1_1device__specific_1_1utils_1_1leading__stride.html":[3,0,207],
"structviennacl_1_1scheduler_1_1lhs__rhs__element.html":[3,0,208],
"classviennacl_1_1ocl_1_1local__mem.html":[3,0,209],
"structviennacl_1_1device__specific_1_1template__base_1_1loop__body__base.html":[3,0,210],
"structviennacl_1_1linalg_1_1lower__tag.html":[3,0,211],
"classviennacl_1_1ocl_1_1map__failure.html":[3,0,212],
"classviennacl_1_1device__specific_1_1mapped__buffer.html":[3,0,213],
"classviennacl_1_1device__specific_1_1mapped__handle.html":[3,0,214],
"classviennacl_1_1device__specific_1_1mapped__host__scalar.html":[3,0,215],
"classviennacl_1_1device__specific_1_1mapped__implicit__matrix.html":[3,0,216],
"classviennacl_1_1device__specific_1_1mapped__implicit__vector.html":[3,0,217],
"classviennacl_1_1device__specific_1_1mapped__matrix.html":[3,0,218],
"classviennacl_1_1device__specific_1_1mapped__matrix__column.html":[3,0,219],
"classviennacl_1_1device__specific_1_1mapped__matrix__diag.html":[3,0,220],
"classviennacl_1_1device__specific_1_1mapped__matrix__product.html":[3,0,221],
"classviennacl_1_1device__specific_1_1mapped__matrix__row.html":[3,0,222],
"classviennacl_1_1device__specific_1_1mapped__object.html":[3,0,223],
"classviennacl_1_1device__specific_1_1mapped__reduction.html":[3,0,224],
"classviennacl_1_1device__specific_1_1mapped__row__wise__reduction.html":[3,0,225],
"classviennacl_1_1device__specific_1_1mapped__scalar.html":[3,0,226],
"classviennacl_1_1device__specific_1_1mapped__scalar__reduction.html":[3,0,227],
"classviennacl_1_1device__specific_1_1mapped__trans.html":[3,0,228],
"classviennacl_1_1device__specific_1_1mapped__vector.html":[3,0,229],
"classviennacl_1_1device__specific_1_1mapped__vector__diag.html":[3,0,230],
"structviennacl_1_1linalg_1_1cuda_1_1mat__mult__matrix__index.html":[3,0,231],
"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix.html":[3,0,232],
"classviennacl_1_1matrix.html":[3,0,233],
"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1matrix__array__wrapper.html":[3,0,234],
"classviennacl_1_1device__specific_1_1matrix__axpy__parameters__type.html":[3,0,235],
"classviennacl_1_1device__specific_1_1matrix__axpy__template.html":[3,0,236],
"classviennacl_1_1matrix__base.html":[3,0,237],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__element.html":[3,0,238],
"classviennacl_1_1matrix__expression.html":[3,0,239],
"classviennacl_1_1matrix__iterator.html":[3,0,240],
"structviennacl_1_1tools_1_1_m_a_t_r_i_x___i_t_e_r_a_t_o_r___i_n_c_r_e_m_e_n_t_e_r.html":[3,0,241],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__legacy.html":[3,0,242],
"structmatrix__maker_3_01ublas_1_1matrix_3_01_t_01_4_00_01_f_01_4.html":[3,0,243],
"structmatrix__maker_3_01ublas_1_1matrix__range_3_01_matrix_t_01_4_00_01_f_01_4.html":[3,0,244],
"structmatrix__maker_3_01ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4.html":[3,0,245],
"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__prod.html":[3,0,246],
"structviennacl_1_1device__specific_1_1matrix__product__parameters.html":[3,0,247],
"classviennacl_1_1device__specific_1_1matrix__product__template.html":[3,0,248],
"classviennacl_1_1matrix__range.html":[3,0,249],
"classviennacl_1_1matrix__range_3_01matrix__range_3_01_matrix_type_01_4_01_4.html":[3,0,250],
"structviennacl_1_1tools_1_1_m_a_t_r_i_x___s_i_z_e___d_e_d_u_c_e_r.html":[3,0,251],
"classviennacl_1_1matrix__slice.html":[3,0,252],
"classviennacl_1_1matrix__slice_3_01matrix__range_3_01_matrix_type_01_4_01_4.html":[3,0,253],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1matrix__solve.html":[3,0,254],
"classviennacl_1_1ocl_1_1mem__copy__overlap.html":[3,0,255],
"classviennacl_1_1backend_1_1mem__handle.html":[3,0,256],
"classviennacl_1_1ocl_1_1mem__object__allocation__failure.html":[3,0,257],
"classviennacl_1_1memory__exception.html":[3,0,258],
"classviennacl_1_1linalg_1_1mixed__precision__cg__tag.html":[3,0,259],
"structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base.html":[3,0,260],
"structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base1_d.html":[3,0,261],
"structviennacl_1_1device__specific_1_1mapped__object_1_1_morph_base2_d.html":[3,0,262],
"classmy__inserter.html":[3,0,263],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1nmf.html":[3,0,264],
"classviennacl_1_1linalg_1_1nmf__config.html":[3,0,265],
"classviennacl_1_1linalg_1_1no__precond.html":[3,0,266],
"structviennacl_1_1device__specific_1_1mapped__object_1_1node__info.html":[3,0,267],
"structviennacl_1_1scheduler_1_1result__of_1_1num__nodes.html":[3,0,268],
"structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01const_01matrix__expression_3_01_l_h_011069f9bf48127b37197927d0585554.html":[3,0,269],
"structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01const_01scalar__expression_3_01_l_h_9d9a43e9a0aea2e2e741ea6a9166750d.html":[3,0,270],
"structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01const_01vector__expression_3_01_l_h_db8a7bb6e522575b18239d7526a98bfc.html":[3,0,271],
"structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01matrix__expression_3_01_l_h_s_00_01_r_h_s_00_01_o_p_01_4_01_4.html":[3,0,272],
"structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01_o_p_01_4_01_4.html":[3,0,273],
"structviennacl_1_1scheduler_1_1result__of_1_1num__nodes_3_01vector__expression_3_01_l_h_s_00_01_r_h_s_00_01_o_p_01_4_01_4.html":[3,0,274],
"structviennacl_1_1scheduler_1_1result__of_1_1numeric__type__id.html":[3,0,275],
"structviennacl_1_1op__abs.html":[3,0,276],
"structviennacl_1_1op__acos.html":[3,0,277],
"structviennacl_1_1op__add.html":[3,0,278],
"structviennacl_1_1linalg_1_1detail_1_1op__applier.html":[3,0,279],
"structviennacl_1_1op__argmax.html":[3,0,280],
"structviennacl_1_1op__argmin.html":[3,0,281],
"structviennacl_1_1op__asin.html":[3,0,282],
"structviennacl_1_1op__assign.html":[3,0,283],
"structviennacl_1_1op__atan.html":[3,0,284],
"structviennacl_1_1op__atan2.html":[3,0,285],
"structviennacl_1_1op__ceil.html":[3,0,286],
"structviennacl_1_1op__column.html":[3,0,287],
"structviennacl_1_1op__cos.html":[3,0,288],
"structviennacl_1_1op__cosh.html":[3,0,289],
"structviennacl_1_1op__div.html":[3,0,290],
"structviennacl_1_1scheduler_1_1op__element.html":[3,0,291],
"structviennacl_1_1op__element__binary.html":[3,0,292],
"structviennacl_1_1op__element__cast.html":[3,0,293],
"structviennacl_1_1op__element__unary.html":[3,0,294],
"structviennacl_1_1op__eq.html":[3,0,295],
"structviennacl_1_1linalg_1_1detail_1_1op__executor.html":[3,0,296],
"structviennacl_1_1op__exp.html":[3,0,297],
"structviennacl_1_1op__fabs.html":[3,0,298],
"structviennacl_1_1op__fdim.html":[3,0,299],
"structviennacl_1_1op__flip__sign.html":[3,0,300],
"structviennacl_1_1op__floor.html":[3,0,301],
"structviennacl_1_1op__fmax.html":[3,0,302],
"structviennacl_1_1op__fmin.html":[3,0,303],
"structviennacl_1_1op__fmod.html":[3,0,304],
"structviennacl_1_1op__geq.html":[3,0,305],
"structviennacl_1_1op__greater.html":[3,0,306],
"structviennacl_1_1op__inner__prod.html":[3,0,307],
"structviennacl_1_1op__inplace__add.html":[3,0,308],
"structviennacl_1_1op__inplace__sub.html":[3,0,309],
"structviennacl_1_1op__leq.html":[3,0,310],
"structviennacl_1_1op__less.html":[3,0,311],
"structviennacl_1_1op__log.html":[3,0,312],
"structviennacl_1_1op__log10.html":[3,0,313],
"structviennacl_1_1op__mat__mat__prod.html":[3,0,314],
"structviennacl_1_1op__matrix__diag.html":[3,0,315],
"structviennacl_1_1op__mult.html":[3,0,316],
"structviennacl_1_1op__neq.html":[3,0,317],
"structviennacl_1_1op__norm__1.html":[3,0,318],
"structviennacl_1_1op__norm__2.html":[3,0,319],
"structviennacl_1_1op__norm__frobenius.html":[3,0,320],
"structviennacl_1_1op__norm__inf.html":[3,0,321],
"structviennacl_1_1op__pow.html":[3,0,322],
"structviennacl_1_1op__prod.html":[3,0,323],
"structviennacl_1_1op__reduce__columns.html":[3,0,324],
"structviennacl_1_1op__reduce__rows.html":[3,0,325],
"structviennacl_1_1op__reduce__vector.html":[3,0,326],
"structviennacl_1_1op__row.html":[3,0,327],
"structviennacl_1_1op__sin.html":[3,0,328],
"structviennacl_1_1op__sinh.html":[3,0,329],
"structviennacl_1_1op__sqrt.html":[3,0,330],
"structviennacl_1_1op__sub.html":[3,0,331],
"structviennacl_1_1op__tan.html":[3,0,332],
"structviennacl_1_1op__tanh.html":[3,0,333],
"structviennacl_1_1op__trans.html":[3,0,334],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info.html":[3,0,335],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__add_01_4.html":[3,0,336],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__assign_01_4.html":[3,0,337],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__column_01_4.html":[3,0,338],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__div_01_4.html":[3,0,339],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__argmax_01_4_01_4.html":[3,0,340],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__argmin_01_4_01_4.html":[3,0,341],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__div_01_4_01_4.html":[3,0,342],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__eq_01_4_01_4.html":[3,0,343],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__fmax_01_4_01_4.html":[3,0,344],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__fmin_01_4_01_4.html":[3,0,345],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__geq_01_4_01_4.html":[3,0,346],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__greater_01_4_01_4.html":[3,0,347],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__leq_01_4_01_4.html":[3,0,348],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__less_01_4_01_4.html":[3,0,349],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__neq_01_4_01_4.html":[3,0,350],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__pow_01_4_01_4.html":[3,0,351],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__binary_3_01op__prod_01_4_01_4.html":[3,0,352],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01char_01_4_01_4.html":[3,0,353],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01double_01_4_01_4.html":[3,0,354],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01float_01_4_01_4.html":[3,0,355],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01int_01_4_01_4.html":[3,0,356],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01long_01_4_01_4.html":[3,0,357],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01short_01_4_01_4.html":[3,0,358],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01char_01_4_01_4.html":[3,0,359],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01int_01_4_01_4.html":[3,0,360],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01long_01_4_01_4.html":[3,0,361],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__cast_3_01unsigned_01short_01_4_01_4.html":[3,0,362],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__abs_01_4_01_4.html":[3,0,363],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__acos_01_4_01_4.html":[3,0,364],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__asin_01_4_01_4.html":[3,0,365],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__atan_01_4_01_4.html":[3,0,366],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__ceil_01_4_01_4.html":[3,0,367],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__cos_01_4_01_4.html":[3,0,368],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__cosh_01_4_01_4.html":[3,0,369],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__exp_01_4_01_4.html":[3,0,370],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__fabs_01_4_01_4.html":[3,0,371],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__floor_01_4_01_4.html":[3,0,372],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__log_01_4_01_4.html":[3,0,373],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__log10_01_4_01_4.html":[3,0,374],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__sin_01_4_01_4.html":[3,0,375],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__sinh_01_4_01_4.html":[3,0,376],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__sqrt_01_4_01_4.html":[3,0,377],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__tan_01_4_01_4.html":[3,0,378],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__element__unary_3_01op__tanh_01_4_01_4.html":[3,0,379],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__flip__sign_01_4.html":[3,0,380],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__inner__prod_01_4.html":[3,0,381],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__inplace__add_01_4.html":[3,0,382],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__inplace__sub_01_4.html":[3,0,383],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__mat__mat__prod_01_4.html":[3,0,384],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__matrix__diag_01_4.html":[3,0,385],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__mult_01_4.html":[3,0,386],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__1_01_4.html":[3,0,387],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__2_01_4.html":[3,0,388],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__norm__inf_01_4.html":[3,0,389],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__prod_01_4.html":[3,0,390],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__columns_3_01_o_p_01_4_01_4.html":[3,0,391],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__rows_3_01_o_p_01_4_01_4.html":[3,0,392],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__reduce__vector_3_01_o_p_01_4_01_4.html":[3,0,393],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__row_01_4.html":[3,0,394],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__sub_01_4.html":[3,0,395],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__trans_01_4.html":[3,0,396],
"structviennacl_1_1scheduler_1_1result__of_1_1op__type__info_3_01op__vector__diag_01_4.html":[3,0,397],
"structviennacl_1_1op__vector__diag.html":[3,0,398],
"classviennacl_1_1ocl_1_1out__of__host__memory.html":[3,0,399],
"classviennacl_1_1ocl_1_1out__of__resources.html":[3,0,400],
"structviennacl_1_1ocl_1_1packed__cl__uint.html":[3,0,401],
"structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html":[3,0,402],
"classviennacl_1_1ocl_1_1platform.html":[3,0,403],
"classviennacl_1_1linalg_1_1power__iter__tag.html":[3,0,404],
"classviennacl_1_1device__specific_1_1tree__parsing_1_1process__traversal.html":[3,0,405],
"classviennacl_1_1ocl_1_1profiling__info__not__available.html":[3,0,406],
"classviennacl_1_1ocl_1_1program.html":[3,0,407],
"structviennacl_1_1device__specific_1_1reduction__parameters.html":[3,0,408],
"classviennacl_1_1device__specific_1_1reduction__template.html":[3,0,409],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html":[3,0,410],
"structviennacl_1_1linalg_1_1detail_1_1_result_data_small.html":[3,0,411],
"structviennacl_1_1row__iteration.html":[3,0,412],
"structviennacl_1_1row__major.html":[3,0,413],
"structviennacl_1_1device__specific_1_1utils_1_1row__major__fun.html":[3,0,414],
"structviennacl_1_1row__major__tag.html":[3,0,415],
"classviennacl_1_1linalg_1_1row__scaling.html":[3,0,416],
"classviennacl_1_1linalg_1_1row__scaling_3_01_matrix_type_00_01true_01_4.html":[3,0,417],
"classviennacl_1_1linalg_1_1row__scaling__tag.html":[3,0,418],
"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1row__wise__reduction.html":[3,0,419],
"structviennacl_1_1device__specific_1_1row__wise__reduction__parameters.html":[3,0,420],
"classviennacl_1_1device__specific_1_1row__wise__reduction__template.html":[3,0,421],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1scalar.html":[3,0,422],
"classviennacl_1_1scalar.html":[3,0,423],
"classviennacl_1_1scalar__expression.html":[3,0,424],
"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__inner__prod_01_4.html":[3,0,425],
"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__1_01_4.html":[3,0,426],
"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__2_01_4.html":[3,0,427],
"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__frobenius_01_4.html":[3,0,428],
"classviennacl_1_1scalar__expression_3_01_l_h_s_00_01_r_h_s_00_01op__norm__inf_01_4.html":[3,0,429],
"classviennacl_1_1scalar__matrix.html":[3,0,430],
"structviennacl_1_1scalar__vector.html":[3,0,431],
"structviennacl_1_1device__specific_1_1utils_1_1scalartype__size__fun.html":[3,0,432],
"classviennacl_1_1tools_1_1detail_1_1sha1.html":[3,0,433],
"classviennacl_1_1tools_1_1shared__ptr.html":[3,0,434],
"structviennacl_1_1device__specific_1_1utils_1_1size1__fun.html":[3,0,435],
"structviennacl_1_1device__specific_1_1utils_1_1size2__fun.html":[3,0,436],
"structviennacl_1_1device__specific_1_1utils_1_1size__fun.html":[3,0,437],
"structviennacl_1_1result__of_1_1size__type.html":[3,0,438],
"classviennacl_1_1sliced__ell__matrix.html":[3,0,439],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1sliced__ell__matrix_3_01_numeric_t_00_01unsigned_01int_01_4.html":[3,0,440],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1spai.html":[3,0,441],
"classviennacl_1_1linalg_1_1spai__precond.html":[3,0,442],
"classviennacl_1_1linalg_1_1spai__precond_3_01viennacl_1_1compressed__matrix_3_01_scalar_type_00_85d4c7cd827146fed2347215919b14e6.html":[3,0,443],
"classviennacl_1_1linalg_1_1detail_1_1spai_1_1spai__tag.html":[3,0,444],
"classviennacl_1_1tools_1_1sparse__matrix__adapted__iterator.html":[3,0,445],
"classviennacl_1_1tools_1_1sparse__matrix__adapter.html":[3,0,446],
"classviennacl_1_1linalg_1_1detail_1_1spai_1_1sparse__vector.html":[3,0,447],
"structviennacl_1_1device__specific_1_1utils_1_1start1__fun.html":[3,0,448],
"structviennacl_1_1device__specific_1_1utils_1_1start2__fun.html":[3,0,449],
"classviennacl_1_1scheduler_1_1statement.html":[3,0,450],
"structviennacl_1_1scheduler_1_1statement__node.html":[3,0,451],
"classviennacl_1_1scheduler_1_1statement__not__supported__exception.html":[3,0,452],
"classviennacl_1_1device__specific_1_1tree__parsing_1_1statement__representation__functor.html":[3,0,453],
"classviennacl_1_1device__specific_1_1statements__container.html":[3,0,454],
"structviennacl_1_1device__specific_1_1utils_1_1stride1__fun.html":[3,0,455],
"structviennacl_1_1device__specific_1_1utils_1_1stride2__fun.html":[3,0,456],
"structviennacl_1_1device__specific_1_1utils_1_1stride__fun.html":[3,0,457],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1svd.html":[3,0,458],
"classviennacl_1_1device__specific_1_1symbolic__binder.html":[3,0,459],
"structviennacl_1_1tag__eigen.html":[3,0,460],
"structviennacl_1_1tag__mtl4.html":[3,0,461],
"structviennacl_1_1tag__none.html":[3,0,462],
"structviennacl_1_1tag__stl.html":[3,0,463],
"structviennacl_1_1tag__ublas.html":[3,0,464],
"structviennacl_1_1tag__viennacl.html":[3,0,465],
"classviennacl_1_1device__specific_1_1template__base.html":[3,0,466],
"classviennacl_1_1device__specific_1_1template__base__impl.html":[3,0,467],
"structtest_data.html":[3,0,468],
"class_timer.html":[3,0,469],
"classviennacl_1_1tools_1_1timer.html":[3,0,470],
"classviennacl_1_1toeplitz__matrix.html":[3,0,471],
"classviennacl_1_1device__specific_1_1tree__parsing_1_1traversal__functor.html":[3,0,472],
"structviennacl_1_1device__specific_1_1builtin__database_1_1database__type_1_1type.html":[3,0,473],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01char_01_4.html":[3,0,474],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01double_01_4.html":[3,0,475],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01float_01_4.html":[3,0,476],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01int_01_4.html":[3,0,477],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01long_01_4.html":[3,0,478],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01short_01_4.html":[3,0,479],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01char_01_4.html":[3,0,480],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01int_01_4.html":[3,0,481],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01long_01_4.html":[3,0,482],
"structviennacl_1_1device__specific_1_1utils_1_1type__to__string_3_01unsigned_01short_01_4.html":[3,0,483],
"structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01double_01_4.html":[3,0,484],
"structviennacl_1_1linalg_1_1cuda_1_1detail_1_1type__to__type2_3_01float_01_4.html":[3,0,485],
"classviennacl_1_1backend_1_1typesafe__host__array.html":[3,0,486],
"classviennacl_1_1backend_1_1typesafe__host__array_3_01_t_00_01true_01_4.html":[3,0,487],
"structviennacl_1_1linalg_1_1unit__lower__tag.html":[3,0,488],
"structviennacl_1_1linalg_1_1unit__upper__tag.html":[3,0,489],
"structviennacl_1_1unit__vector.html":[3,0,490],
"classviennacl_1_1ocl_1_1unknown__error.html":[3,0,491],
"structviennacl_1_1linalg_1_1upper__tag.html":[3,0,492],
"structviennacl_1_1result__of_1_1value__type.html":[3,0,493],
"classviennacl_1_1vandermonde__matrix.html":[3,0,494],
"classviennacl_1_1vector.html":[3,0,495],
"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector.html":[3,0,496],
"classviennacl_1_1linalg_1_1host__based_1_1detail_1_1vector__array__wrapper.html":[3,0,497],
"classviennacl_1_1device__specific_1_1vector__axpy__parameters.html":[3,0,498],
"classviennacl_1_1device__specific_1_1vector__axpy__template.html":[3,0,499],
"classviennacl_1_1vector__base.html":[3,0,500],
"structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__element.html":[3,0,501],
"classviennacl_1_1vector__expression.html":[3,0,502],
"classviennacl_1_1vector__iterator.html":[3,0,503],
"classviennacl_1_1linalg_1_1opencl_1_1kernels_1_1vector__multi__inner__prod.html":[3,0,504],
"classviennacl_1_1vector__range.html":[3,0,505],
"classviennacl_1_1vector__range_3_01vector__range_3_01_vector_type_01_4_01_4.html":[3,0,506],
"classviennacl_1_1vector__slice.html":[3,0,507],
"classviennacl_1_1vector__slice_3_01vector__slice_3_01_vector_type_01_4_01_4.html":[3,0,508],
"classviennacl_1_1vector__tuple.html":[3,0,509],
"struct_vienna_c_l_backend__impl.html":[3,0,510],
"struct_vienna_c_l_c_u_d_a_backend__impl.html":[3,0,511],
"struct_vienna_c_l_host_backend__impl.html":[3,0,512],
"struct_vienna_c_l_host_scalar__impl.html":[3,0,513],
"struct_vienna_c_l_matrix__impl.html":[3,0,514],
"struct_vienna_c_l_open_c_l_backend__impl.html":[3,0,515],
"struct_vienna_c_l_scalar__impl.html":[3,0,516],
"struct_vienna_c_l_vector__impl.html":[3,0,517],
"classviennacl_1_1linalg_1_1detail_1_1z__handler.html":[3,0,518],
"classviennacl_1_1linalg_1_1detail_1_1z__handler_3_01_vector_t_00_01viennacl_1_1linalg_1_1no__precond_01_4.html":[3,0,519],
"classviennacl_1_1zero__matrix.html":[3,0,520],
"structviennacl_1_1zero__vector.html":[3,0,521],
"classes.html":[3,1],
"hierarchy.html":[3,2],
"functions.html":[3,3,0],
"functions.html":[3,3,0,0],
"functions_0x62.html":[3,3,0,1],
"functions_0x63.html":[3,3,0,2],
"functions_0x64.html":[3,3,0,3],
"functions_0x65.html":[3,3,0,4],
"functions_0x66.html":[3,3,0,5],
"functions_0x67.html":[3,3,0,6],
"functions_0x68.html":[3,3,0,7],
"functions_0x69.html":[3,3,0,8],
"functions_0x6a.html":[3,3,0,9],
"functions_0x6b.html":[3,3,0,10],
"functions_0x6c.html":[3,3,0,11],
"functions_0x6d.html":[3,3,0,12],
"functions_0x6e.html":[3,3,0,13],
"functions_0x6f.html":[3,3,0,14],
"functions_0x70.html":[3,3,0,15],
"functions_0x71.html":[3,3,0,16],
"functions_0x72.html":[3,3,0,17],
"functions_0x73.html":[3,3,0,18],
"functions_0x74.html":[3,3,0,19],
"functions_0x75.html":[3,3,0,20],
"functions_0x76.html":[3,3,0,21],
"functions_0x77.html":[3,3,0,22],
"functions_0x7a.html":[3,3,0,23],
"functions_0x7e.html":[3,3,0,24],
"functions_func.html":[3,3,1],
"functions_func.html":[3,3,1,0],
"functions_func_0x62.html":[3,3,1,1],
"functions_func_0x63.html":[3,3,1,2],
"functions_func_0x64.html":[3,3,1,3],
"functions_func_0x65.html":[3,3,1,4],
"functions_func_0x66.html":[3,3,1,5],
"functions_func_0x67.html":[3,3,1,6],
"functions_func_0x68.html":[3,3,1,7],
"functions_func_0x69.html":[3,3,1,8],
"functions_func_0x6a.html":[3,3,1,9],
"functions_func_0x6b.html":[3,3,1,10],
"functions_func_0x6c.html":[3,3,1,11],
"functions_func_0x6d.html":[3,3,1,12],
"functions_func_0x6e.html":[3,3,1,13],
"functions_func_0x6f.html":[3,3,1,14],
"functions_func_0x70.html":[3,3,1,15],
"functions_func_0x71.html":[3,3,1,16],
"functions_func_0x72.html":[3,3,1,17],
"functions_func_0x73.html":[3,3,1,18],
"functions_func_0x74.html":[3,3,1,19],
"functions_func_0x75.html":[3,3,1,20],
"functions_func_0x76.html":[3,3,1,21],
"functions_func_0x77.html":[3,3,1,22],
"functions_func_0x7a.html":[3,3,1,23],
"functions_func_0x7e.html":[3,3,1,24],
"functions_vars.html":[3,3,2],
"functions_vars.html":[3,3,2,0],
"functions_vars_0x62.html":[3,3,2,1],
"functions_vars_0x63.html":[3,3,2,2],
"functions_vars_0x64.html":[3,3,2,3],
"functions_vars_0x65.html":[3,3,2,4],
"functions_vars_0x66.html":[3,3,2,5],
"functions_vars_0x67.html":[3,3,2,6],
"functions_vars_0x68.html":[3,3,2,7],
"functions_vars_0x69.html":[3,3,2,8],
"functions_vars_0x6a.html":[3,3,2,9],
"functions_vars_0x6b.html":[3,3,2,10],
"functions_vars_0x6c.html":[3,3,2,11],
"functions_vars_0x6d.html":[3,3,2,12],
"functions_vars_0x6e.html":[3,3,2,13],
"functions_vars_0x6f.html":[3,3,2,14],
"functions_vars_0x70.html":[3,3,2,15],
"functions_vars_0x72.html":[3,3,2,16],
"functions_vars_0x73.html":[3,3,2,17],
"functions_vars_0x74.html":[3,3,2,18],
"functions_vars_0x76.html":[3,3,2,19],
"functions_vars_0x77.html":[3,3,2,20],
"functions_type.html":[3,3,3],
"functions_type.html":[3,3,3,0],
"functions_type_0x64.html":[3,3,3,1],
"functions_type_0x65.html":[3,3,3,2],
"functions_type_0x68.html":[3,3,3,3],
"functions_type_0x69.html":[3,3,3,4],
"functions_type_0x6d.html":[3,3,3,5],
"functions_type_0x6f.html":[3,3,3,6],
"functions_type_0x70.html":[3,3,3,7],
"functions_type_0x72.html":[3,3,3,8],
"functions_type_0x73.html":[3,3,3,9],
"functions_type_0x74.html":[3,3,3,10],
"functions_type_0x76.html":[3,3,3,11],
"functions_enum.html":[3,3,4],
"functions_eval.html":[3,3,5],
"functions_rela.html":[3,3,6],
"files.html":[4,0],
"changelog.html":[4,0,0],
"benchmark-utils_8hpp.html":[4,0,1],
"dense__blas_8cpp.html":[4,0,2],
"direct__solve_8cpp.html":[4,0,3],
"opencl_8cpp.html":[4,0,4],
"benchmarks_2qr_8cpp.html":[4,0,5],
"benchmarks_2scheduler_8cpp.html":[4,0,6],
"solver_8cpp.html":[4,0,7],
"examples_2benchmarks_2sparse_8cpp.html":[4,0,8],
"amg_8cpp.html":[4,0,9],
"bandwidth-reduction_8cpp.html":[4,0,10],
"examples_2tutorial_2bisect_8cpp.html":[4,0,11],
"examples_2tutorial_2blas1_8cpp.html":[4,0,12],
"examples_2tutorial_2blas2_8cpp.html":[4,0,13],
"examples_2tutorial_2blas3_8cpp.html":[4,0,14],
"blas3range_8cpp.html":[4,0,15],
"custom-context_8cpp.html":[4,0,16],
"custom-kernels_8cpp.html":[4,0,17],
"eigen-with-viennacl_8cpp.html":[4,0,18],
"fft_8cpp.html":[4,0,19],
"iterative-eigen_8cpp.html":[4,0,20],
"iterative-mtl4_8cpp.html":[4,0,21],
"iterative-ublas_8cpp.html":[4,0,22],
"iterative_8cpp.html":[4,0,23],
"lanczos_8cpp.html":[4,0,24],
"least-squares_8cpp.html":[4,0,25],
"libviennacl_8cpp.html":[4,0,26],
"matrix-range_8cpp.html":[4,0,27],
"mtl4-with-viennacl_8cpp.html":[4,0,28],
"multithreaded_8cpp.html":[4,0,29],
"multithreaded__cg_8cpp.html":[4,0,30],
"examples_2tutorial_2nmf_8cpp.html":[4,0,31],
"power-iter_8cpp.html":[4,0,32],
"tutorial_2qr_8cpp.html":[4,0,33],
"examples_2tutorial_2qr__method_8cpp.html":[4,0,34],
"examples_2tutorial_2_random_8hpp.html":[4,0,35],
"tutorial_2scheduler_8cpp.html":[4,0,36],
"examples_2tutorial_2scheduler__matrix_8cpp.html":[4,0,37],
"spai_8cpp.html":[4,0,38],
"examples_2tutorial_2sparse_8cpp.html":[4,0,39],
"examples_2tutorial_2structured-matrices_8cpp.html":[4,0,40],
"tql2_8cpp.html":[4,0,41],
"vector-io_8hpp.html":[4,0,42],
"vector-range_8cpp.html":[4,0,43],
"viennacl-info_8cpp.html":[4,0,44],
"wrap-host-buffer_8cpp.html":[4,0,45],
"viennacl_8hpp.html":[4,0,46],
"backend_8cpp.html":[4,0,47],
"libviennacl_2src_2blas1_8cpp.html":[4,0,48],
"blas1__host_8cpp.html":[4,0,49],
"blas1__opencl_8cpp.html":[4,0,50],
"libviennacl_2src_2blas2_8cpp.html":[4,0,51],
"blas2__host_8cpp.html":[4,0,52],
"blas2__opencl_8cpp.html":[4,0,53],
"libviennacl_2src_2blas3_8cpp.html":[4,0,54],
"blas3_8hpp.html":[4,0,55],
"blas3__host_8cpp.html":[4,0,56],
"blas3__opencl_8cpp.html":[4,0,57],
"init__matrix_8hpp.html":[4,0,58],
"init__vector_8hpp.html":[4,0,59],
"viennacl__private_8hpp.html":[4,0,60],
"tests_2src_2bisect_8cpp.html":[4,0,61],
"blas3__solve_8cpp.html":[4,0,62],
"external__1_8cpp.html":[4,0,63],
"external__2_8cpp.html":[4,0,64],
"fft__1d_8cpp.html":[4,0,65],
"fft__2d_8cpp.html":[4,0,66],
"generator__blas1_8cpp.html":[4,0,67],
"generator__blas2_8cpp.html":[4,0,68],
"generator__blas3_8cpp.html":[4,0,69],
"global__variables_8cpp.html":[4,0,70],
"iterators_8cpp.html":[4,0,71],
"libviennacl__blas1_8cpp.html":[4,0,72],
"libviennacl__blas2_8cpp.html":[4,0,73],
"libviennacl__blas3_8cpp.html":[4,0,74],
"matrix__col__double_8cpp.html":[4,0,75],
"matrix__col__float_8cpp.html":[4,0,76],
"matrix__col__int_8cpp.html":[4,0,77],
"matrix__float__double_8hpp.html":[4,0,78],
"matrix__int_8hpp.html":[4,0,79],
"matrix__product__double_8cpp.html":[4,0,80],
"matrix__product__float_8cpp.html":[4,0,81],
"matrix__product__float__double_8hpp.html":[4,0,82],
"matrix__row__double_8cpp.html":[4,0,83],
"matrix__row__float_8cpp.html":[4,0,84],
"matrix__row__int_8cpp.html":[4,0,85],
"matrix__vector_8cpp.html":[4,0,86],
"matrix__vector__int_8cpp.html":[4,0,87],
"tests_2src_2nmf_8cpp.html":[4,0,88],
"tests_2src_2qr__method_8cpp.html":[4,0,89],
"qr__method__func_8cpp.html":[4,0,90],
"tests_2src_2_random_8hpp.html":[4,0,91],
"scalar_8cpp.html":[4,0,92],
"scan_8cpp.html":[4,0,93],
"tests_2src_2scheduler__matrix_8cpp.html":[4,0,94],
"scheduler__matrix__matrix_8cpp.html":[4,0,95],
"scheduler__matrix__vector_8cpp.html":[4,0,96],
"scheduler__sparse_8cpp.html":[4,0,97],
"scheduler__vector_8cpp.html":[4,0,98],
"tests_2src_2sparse_8cpp.html":[4,0,99],
"spmdm_8cpp.html":[4,0,100],
"tests_2src_2structured-matrices_8cpp.html":[4,0,101],
"svd_8cpp.html":[4,0,102],
"tql_8cpp.html":[4,0,103],
"vector__float__double_8cpp.html":[4,0,104],
"vector__int_8cpp.html":[4,0,105],
"vector__multi__inner__prod_8cpp.html":[4,0,106],
"vector__uint_8cpp.html":[4,0,107],
"circulant__matrix_8hpp.html":[4,0,108],
"compressed__compressed__matrix_8hpp.html":[4,0,109],
"compressed__matrix_8hpp.html":[4,0,110],
"context_8hpp.html":[4,0,111],
"coordinate__matrix_8hpp.html":[4,0,112],
"ell__matrix_8hpp.html":[4,0,113],
"fft_8hpp.html":[4,0,114],
"forwards_8h.html":[4,0,115],
"hankel__matrix_8hpp.html":[4,0,116],
"hyb__matrix_8hpp.html":[4,0,117],
"matrix_8hpp.html":[4,0,118],
"matrix__def_8hpp.html":[4,0,119],
"matrix__proxy_8hpp.html":[4,0,120],
"range_8hpp.html":[4,0,121],
"scalar_8hpp.html":[4,0,122],
"slice_8hpp.html":[4,0,123],
"sliced__ell__matrix_8hpp.html":[4,0,124],
"toeplitz__matrix_8hpp.html":[4,0,125],
"vandermonde__matrix_8hpp.html":[4,0,126],
"vector_8hpp.html":[4,0,127],
"vector__def_8hpp.html":[4,0,128],
"vector__proxy_8hpp.html":[4,0,129],
"version_8hpp.html":[4,0,130],
"cpu__ram_8hpp.html":[4,0,131],
"cuda_8hpp.html":[4,0,132],
"mem__handle_8hpp.html":[4,0,133],
"memory_8hpp.html":[4,0,134],
"opencl_8hpp.html":[4,0,135],
"backend_2util_8hpp.html":[4,0,136],
"device__specific_2execute_8hpp.html":[4,0,137],
"execution__handler_8hpp.html":[4,0,138],
"device__specific_2forwards_8h.html":[4,0,139],
"lazy__program__compiler_8hpp.html":[4,0,140],
"mapped__objects_8hpp.html":[4,0,141],
"tree__parsing_8hpp.html":[4,0,142],
"device__specific_2utils_8hpp.html":[4,0,143],
"device__specific_2builtin__database_2common_8hpp.html":[4,0,144],
"matrix__axpy_8hpp.html":[4,0,145],
"matrix__product_8hpp.html":[4,0,146],
"reduction_8hpp.html":[4,0,147],
"row__wise__reduction_8hpp.html":[4,0,148],
"vector__axpy_8hpp.html":[4,0,149],
"accelerator_2fallback_8hpp.html":[4,0,150],
"cpu_2fallback_8hpp.html":[4,0,151],
"gpu_2fallback_8hpp.html":[4,0,152],
"cypress_8hpp.html":[4,0,153],
"devastator_8hpp.html":[4,0,154],
"tahiti_8hpp.html":[4,0,155],
"hawaii_8hpp.html":[4,0,156],
"geforce__gt__540m_8hpp.html":[4,0,157],
"geforce__gtx__580_8hpp.html":[4,0,158],
"tesla__k20m_8hpp.html":[4,0,159],
"matrix__axpy__template_8hpp.html":[4,0,160],
"matrix__product__template_8hpp.html":[4,0,161],
"reduction__template_8hpp.html":[4,0,162],
"row__wise__reduction__template_8hpp.html":[4,0,163],
"template__base_8hpp.html":[4,0,164],
"device__specific_2templates_2utils_8hpp.html":[4,0,165],
"vector__axpy__template_8hpp.html":[4,0,166],
"matrix__market_8hpp.html":[4,0,167],
"amg_8hpp.html":[4,0,168],
"bicgstab_8hpp.html":[4,0,169],
"bisect_8hpp.html":[4,0,170],
"bisect__gpu_8hpp.html":[4,0,171],
"cg_8hpp.html":[4,0,172],
"circulant__matrix__operations_8hpp.html":[4,0,173],
"direct__solve_8hpp.html":[4,0,174],
"eig_8hpp.html":[4,0,175],
"fft__operations_8hpp.html":[4,0,176],
"gmres_8hpp.html":[4,0,177],
"hankel__matrix__operations_8hpp.html":[4,0,178],
"ichol_8hpp.html":[4,0,179],
"ilu_8hpp.html":[4,0,180],
"inner__prod_8hpp.html":[4,0,181],
"iterative__operations_8hpp.html":[4,0,182],
"jacobi__precond_8hpp.html":[4,0,183],
"lanczos_8hpp.html":[4,0,184],
"lu_8hpp.html":[4,0,185],
"matrix__operations_8hpp.html":[4,0,186],
"misc__operations_8hpp.html":[4,0,187],
"mixed__precision__cg_8hpp.html":[4,0,188],
"nmf__operations_8hpp.html":[4,0,189],
"norm__1_8hpp.html":[4,0,190],
"norm__2_8hpp.html":[4,0,191],
"norm__frobenius_8hpp.html":[4,0,192],
"norm__inf_8hpp.html":[4,0,193],
"power__iter_8hpp.html":[4,0,194],
"prod_8hpp.html":[4,0,195],
"qr-method-common_8hpp.html":[4,0,196],
"qr-method_8hpp.html":[4,0,197],
"qr_8hpp.html":[4,0,198],
"reduce_8hpp.html":[4,0,199],
"row__scaling_8hpp.html":[4,0,200],
"scalar__operations_8hpp.html":[4,0,201],
"spai_8hpp.html":[4,0,202],
"sparse__matrix__operations_8hpp.html":[4,0,203],
"svd_8hpp.html":[4,0,204],
"toeplitz__matrix__operations_8hpp.html":[4,0,205],
"tql2_8hpp.html":[4,0,206],
"tred2_8hpp.html":[4,0,207],
"vandermonde__matrix__operations_8hpp.html":[4,0,208],
"vector__operations_8hpp.html":[4,0,209],
"cuda_2bisect__kernel__calls_8hpp.html":[4,0,210],
"bisect__kernel__large_8hpp.html":[4,0,211],
"bisect__kernel__large__multi_8hpp.html":[4,0,212],
"bisect__kernel__large__onei_8hpp.html":[4,0,213],
"bisect__kernel__small_8hpp.html":[4,0,214],
"bisect__util_8hpp.html":[4,0,215],
"linalg_2cuda_2common_8hpp.html":[4,0,216],
"cuda_2direct__solve_8hpp.html":[4,0,217],
"cuda_2fft__operations_8hpp.html":[4,0,218],
"cuda_2iterative__operations_8hpp.html":[4,0,219],
"cuda_2matrix__operations_8hpp.html":[4,0,220],
"matrix__operations__col_8hpp.html":[4,0,221],
"matrix__operations__prod_8hpp.html":[4,0,222],
"matrix__operations__row_8hpp.html":[4,0,223],
"cuda_2misc__operations_8hpp.html":[4,0,224],
"cuda_2nmf__operations_8hpp.html":[4,0,225],
"cuda_2scalar__operations_8hpp.html":[4,0,226],
"cuda_2sparse__matrix__operations_8hpp.html":[4,0,227],
"sparse__matrix__operations__solve_8hpp.html":[4,0,228],
"cuda_2vector__operations_8hpp.html":[4,0,229],
"op__applier_8hpp.html":[4,0,230],
"op__executor_8hpp.html":[4,0,231],
"amg__base_8hpp.html":[4,0,232],
"amg__coarse_8hpp.html":[4,0,233],
"amg__debug_8hpp.html":[4,0,234],
"amg__interpol_8hpp.html":[4,0,235],
"detail_2bisect_2bisect__kernel__calls_8hpp.html":[4,0,236],
"bisect__large_8hpp.html":[4,0,237],
"bisect__small_8hpp.html":[4,0,238],
"config_8hpp.html":[4,0,239],
"gerschgorin_8hpp.html":[4,0,240],
"structs_8hpp.html":[4,0,241],
"linalg_2detail_2bisect_2util_8hpp.html":[4,0,242],
"block__ilu_8hpp.html":[4,0,243],
"linalg_2detail_2ilu_2common_8hpp.html":[4,0,244],
"ilu0_8hpp.html":[4,0,245],
"ilut_8hpp.html":[4,0,246],
"block__matrix_8hpp.html":[4,0,247],
"block__vector_8hpp.html":[4,0,248],
"fspai_8hpp.html":[4,0,249],
"detail_2spai_2qr_8hpp.html":[4,0,250],
"small__matrix_8hpp.html":[4,0,251],
"spai-dynamic_8hpp.html":[4,0,252],
"spai-static_8hpp.html":[4,0,253],
"detail_2spai_2spai_8hpp.html":[4,0,254],
"spai__tag_8hpp.html":[4,0,255],
"sparse__vector_8hpp.html":[4,0,256],
"linalg_2host__based_2common_8hpp.html":[4,0,257],
"host__based_2direct__solve_8hpp.html":[4,0,258],
"host__based_2fft__operations_8hpp.html":[4,0,259],
"host__based_2iterative__operations_8hpp.html":[4,0,260],
"host__based_2matrix__operations_8hpp.html":[4,0,261],
"host__based_2misc__operations_8hpp.html":[4,0,262],
"host__based_2nmf__operations_8hpp.html":[4,0,263],
"host__based_2scalar__operations_8hpp.html":[4,0,264],
"host__based_2sparse__matrix__operations_8hpp.html":[4,0,265],
"sse__blas_8hpp.html":[4,0,266],
"sse__kernels_8hpp.html":[4,0,267],
"host__based_2vector__operations_8hpp.html":[4,0,268],
"opencl_2bisect__kernel__calls_8hpp.html":[4,0,269],
"linalg_2opencl_2common_8hpp.html":[4,0,270],
"opencl_2direct__solve_8hpp.html":[4,0,271],
"opencl_2fft__operations_8hpp.html":[4,0,272],
"opencl_2iterative__operations_8hpp.html":[4,0,273],
"opencl_2matrix__operations_8hpp.html":[4,0,274],
"opencl_2misc__operations_8hpp.html":[4,0,275],
"opencl_2nmf__operations_8hpp.html":[4,0,276],
"opencl_2scalar__operations_8hpp.html":[4,0,277],
"opencl_2sparse__matrix__operations_8hpp.html":[4,0,278],
"opencl_2vandermonde__matrix__operations_8hpp.html":[4,0,279],
"opencl_2vector__operations_8hpp.html":[4,0,280],
"opencl_2kernels_2bisect_8hpp.html":[4,0,281],
"linalg_2opencl_2kernels_2compressed__compressed__matrix_8hpp.html":[4,0,282],
"linalg_2opencl_2kernels_2compressed__matrix_8hpp.html":[4,0,283],
"linalg_2opencl_2kernels_2coordinate__matrix_8hpp.html":[4,0,284],
"linalg_2opencl_2kernels_2ell__matrix_8hpp.html":[4,0,285],
"linalg_2opencl_2kernels_2fft_8hpp.html":[4,0,286],
"linalg_2opencl_2kernels_2hyb__matrix_8hpp.html":[4,0,287],
"opencl_2kernels_2ilu_8hpp.html":[4,0,288],
"iterative_8hpp.html":[4,0,289],
"linalg_2opencl_2kernels_2matrix_8hpp.html":[4,0,290],
"matrix__solve_8hpp.html":[4,0,291],
"nmf_8hpp.html":[4,0,292],
"linalg_2opencl_2kernels_2scalar_8hpp.html":[4,0,293],
"linalg_2opencl_2kernels_2sliced__ell__matrix_8hpp.html":[4,0,294],
"opencl_2kernels_2spai_8hpp.html":[4,0,295],
"opencl_2kernels_2svd_8hpp.html":[4,0,296],
"linalg_2opencl_2kernels_2vector_8hpp.html":[4,0,297],
"enable__if_8hpp.html":[4,0,298],
"predicate_8hpp.html":[4,0,299],
"result__of_8hpp.html":[4,0,300],
"tag__of_8hpp.html":[4,0,301],
"bandwidth__reduction_8hpp.html":[4,0,302],
"cuthill__mckee_8hpp.html":[4,0,303],
"gibbs__poole__stockmeyer_8hpp.html":[4,0,304],
"backend_8hpp.html":[4,0,305],
"command__queue_8hpp.html":[4,0,306],
"ocl_2context_8hpp.html":[4,0,307],
"device_8hpp.html":[4,0,308],
"device__utils_8hpp.html":[4,0,309],
"enqueue_8hpp.html":[4,0,310],
"error_8hpp.html":[4,0,311],
"ocl_2forwards_8h.html":[4,0,312],
"ocl_2handle_8hpp.html":[4,0,313],
"kernel_8hpp.html":[4,0,314],
"local__mem_8hpp.html":[4,0,315],
"platform_8hpp.html":[4,0,316],
"program_8hpp.html":[4,0,317],
"ocl_2utils_8hpp.html":[4,0,318],
"gaussian_8hpp.html":[4,0,319],
"uniform_8hpp.html":[4,0,320],
"rand_2utils_8hpp.html":[4,0,321],
"scheduler_2execute_8hpp.html":[4,0,322],
"execute__axbx_8hpp.html":[4,0,323],
"execute__elementwise_8hpp.html":[4,0,324],
"execute__generic__dispatcher_8hpp.html":[4,0,325],
"execute__matrix__dispatcher_8hpp.html":[4,0,326],
"execute__matrix__prod_8hpp.html":[4,0,327],
"execute__scalar__assign_8hpp.html":[4,0,328],
"execute__scalar__dispatcher_8hpp.html":[4,0,329],
"execute__util_8hpp.html":[4,0,330],
"execute__vector__dispatcher_8hpp.html":[4,0,331],
"scheduler_2forwards_8h.html":[4,0,332],
"io_8hpp.html":[4,0,333],
"preset_8hpp.html":[4,0,334],
"adapter_8hpp.html":[4,0,335],
"entry__proxy_8hpp.html":[4,0,336],
"matrix__generation_8hpp.html":[4,0,337],
"matrix__size__deducer_8hpp.html":[4,0,338],
"sha1_8hpp.html":[4,0,339],
"shared__ptr_8hpp.html":[4,0,340],
"timer_8hpp.html":[4,0,341],
"tools_8hpp.html":[4,0,342],
"clear_8hpp.html":[4,0,343],
"traits_2context_8hpp.html":[4,0,344],
"fill_8hpp.html":[4,0,345],
"traits_2handle_8hpp.html":[4,0,346],
"row__major_8hpp.html":[4,0,347],
"size_8hpp.html":[4,0,348],
"start_8hpp.html":[4,0,349],
"stride_8hpp.html":[4,0,350],
"globals.html":[4,1,0],
"globals.html":[4,1,0,0],
"globals_0x62.html":[4,1,0,1],
"globals_0x63.html":[4,1,0,2],
"globals_0x64.html":[4,1,0,3],
"globals_0x65.html":[4,1,0,4],
"globals_0x66.html":[4,1,0,5],
"globals_0x67.html":[4,1,0,6],
"globals_0x68.html":[4,1,0,7],
"globals_0x69.html":[4,1,0,8],
"globals_0x6d.html":[4,1,0,9],
"globals_0x6e.html":[4,1,0,10],
"globals_0x6f.html":[4,1,0,11],
"globals_0x70.html":[4,1,0,12],
"globals_0x72.html":[4,1,0,13],
"globals_0x73.html":[4,1,0,14],
"globals_0x74.html":[4,1,0,15],
"globals_0x75.html":[4,1,0,16],
"globals_0x76.html":[4,1,0,17],
"globals_0x79.html":[4,1,0,18],
"globals_func.html":[4,1,1],
"globals_func.html":[4,1,1,0],
"globals_func_0x63.html":[4,1,1,1],
"globals_func_0x64.html":[4,1,1,2],
"globals_func_0x66.html":[4,1,1,3],
"globals_func_0x67.html":[4,1,1,4],
"globals_func_0x68.html":[4,1,1,5],
"globals_func_0x69.html":[4,1,1,6],
"globals_func_0x6d.html":[4,1,1,7],
"globals_func_0x6f.html":[4,1,1,8],
"globals_func_0x70.html":[4,1,1,9],
"globals_func_0x72.html":[4,1,1,10],
"globals_func_0x73.html":[4,1,1,11],
"globals_func_0x74.html":[4,1,1,12],
"globals_func_0x76.html":[4,1,1,13],
"globals_vars.html":[4,1,2],
"globals_type.html":[4,1,3],
"globals_enum.html":[4,1,4],
"globals_eval.html":[4,1,5],
"globals_defs.html":[4,1,6],
"examples.html":[5],
"_algebraic_01_multigrid_01_preconditioners-example.html":[5,0],
"_b_l_a_s_01_level_011_01_functionality-example.html":[5,1],
"_b_l_a_s_01_level_012_01_functionality-example.html":[5,2],
"_b_l_a_s_01_level_013_01_functionality-example.html":[5,3],
"_b_l_a_s-like_01_shared_01_library-example.html":[5,4],
"_device_01_informations-example.html":[5,5],
"_eigen_1_01_exchange_01data_01with_01_vienna_c_l-example.html":[5,6],
"_eigen_1_01_iterative_01_solvers_01from_01_vienna_c_l-example.html":[5,7],
"_eigenvalues_1_01_bisection_01_method-example.html":[5,8],
"_eigenvalues_1_01_lanczos'_01_method-example.html":[5,9],
"_eigenvalues_1_01_power_01_iteration-example.html":[5,10],
"_eigenvalues_1_01_q_r_01method_01for_01dense_01systems-example.html":[5,11],
"_eigenvalues_1_01_symmetric_01_tridiagonal_01_matrices-example.html":[5,12],
"_fast_01_fourier_01_transform-example.html":[5,13],
"_iterative_01_solvers-example.html":[5,14],
"_matrix_01_bandwidth_01_reduction-example.html":[5,15],
"_method_01of_01_least_01_squares-example.html":[5,16],
"_m_t_l4_1_01_exchange_01data_01with_01_vienna_c_l-example.html":[5,17],
"_m_t_l4_1_01_iterative_01_solvers-example.html":[5,18],
"_multiple_01_conjugate_01_gradient_01_solvers_01_07one_01per_01_context_08-example.html":[5,19],
"_multithreaded_01_use_01of_01_vienna_c_l-example.html":[5,20],
"_nonnegative_01_matrix_01_factorization-example.html":[5,21],
"_open_c_l_1_01_user-_defined_01_kernels-example.html":[5,22],
"_open_c_l_1_01_user-_provided_01_contexts-example.html":[5,23],
"_operations_01with_01_submatrices-example.html":[5,24],
"_q_r_01_factorization_01of_01_dense_01_matrices-example.html":[5,25],
"_sparse_01_approximate_01_inverse_01_preconditioner-example.html":[5,26],
"_sparse_01_matrices-example.html":[5,27],
"_structured_01_matrices-example.html":[5,28],
"u_b_l_a_s_1_01_iterative_01_solvers-example.html":[5,29],
"_using_01the_01_low-_level_01_scheduler-example.html":[5,30],
"_vector_01_ranges-example.html":[5,31],
"_wrapping_01_user-provided_01_buffers-example.html":[5,32]
};
